trace
xrpl_
common_
stdlib
0.9.0
trace
Sections
Parameters
In xrpl_
common_
stdlib::
host::
trace
xrpl_common_stdlib
::
host
::
trace
Function
trace
pub fn trace(msg: &
str
)
Write the contents of a message to the xrpld trace log.

Parameters
msg
: A str ref pointing to an array of bytes containing UTF-8 characters.