trace_hex

Function trace_hex 

pub fn trace_hex(msg: &str, data: &[u8])
Write a message and a data buffer to the xrpld trace log, hex-encoded by the host.

Parameters

  • msg: A str ref pointing to an array of bytes containing UTF-8 characters.
  • data: The bytes to emit alongside msg.