pub fn trace_num(msg: &str, number: i64)Expand description
Write the contents of a message, and a number, to the xrpld trace log.
Parameters
msg: A str ref pointing to an array of bytes containing UTF-8 characters.number: A number to emit into the trace logs.