Function trace_num_unsigned
Source pub fn trace_num_unsigned(msg: &str, number: u64)
Write the contents of a message, and an unsigned number, to the xrpld trace log. Use this
over trace_num for values above i64::MAX.
Parameters
msg: A str ref pointing to an array of bytes containing UTF-8 characters.
number: A number to emit into the trace logs.