pub fn trace_text(msg: &str, data: &[u8])Expand description
Write a message and a data buffer to the xrpld trace log, printed verbatim as text.
Parameters
msg: A str ref pointing to an array of bytes containing UTF-8 characters.data: The bytes to emit alongsidemsg.